.. _about_author:

About the Author
------------------------------------------------------------------------------
**Sanhe Hu** is a passionate **Python Developer** and **AWS Solution Architect** from 2010. His expertise and keen interests lie in mastering and innovating within the domains of **Cloud Computing, AWS Services, Machine Learning, Big Data Architecture, Serverless Computing, Game Tech, and Open Source**.

- My popular open sources: https://github.com/MacHu-GWU
